summaryrefslogtreecommitdiffstats
path: root/kmail/kmstartup.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-04-14 20:16:30 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-04-14 20:16:30 +0000
commit1c93fca14d9ce37499bcfdf994c660186a0b6f17 (patch)
treef2defe163a805a9e34a2142dfde4cdb5e49241e7 /kmail/kmstartup.cpp
parent67e29a054cfcb1b0d2fe6b0a316cf6b3eec087b7 (diff)
downloadtdepim-1c93fca14d9ce37499bcfdf994c660186a0b6f17.tar.gz
tdepim-1c93fca14d9ce37499bcfdf994c660186a0b6f17.zip
Enable kdepim compilation under Qt4
This will likely break Qt3 compilation temporarily, which is an unintended side effect. A third and final kdepim commit will repair Qt3 compilation shortly. git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdepim@1227946 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kmail/kmstartup.cpp')
-rw-r--r--kmail/kmstartup.cpp16
1 files changed, 8 insertions, 8 deletions
diff --git a/kmail/kmstartup.cpp b/kmail/kmstartup.cpp
index 943a3a2d..fd3d7bd7 100644
--- a/kmail/kmstartup.cpp
+++ b/kmail/kmstartup.cpp
@@ -165,7 +165,7 @@ void lockOrDie() {
// On linux with /proc we can even check that it's really kmail and not something else
char path_buffer[MAXPATHLEN + 1];
path_buffer[MAXPATHLEN] = 0;
- const TQString procPath = TQString("/proc/%1/exe").arg(oldPid);
+ const TQString procPath = TQString("/proc/%1/exe").tqarg(oldPid);
const int length = readlink (procPath.latin1(), path_buffer, MAXPATHLEN);
if ( length == -1 ) // not such pid
first_instance = true;
@@ -173,7 +173,7 @@ void lockOrDie() {
path_buffer[length] = '\0';
const TQString path = TQFile::decodeName(path_buffer);
kdDebug() << k_funcinfo << path << endl;
- const int pos = path.findRev('/');
+ const int pos = path.tqfindRev('/');
const TQString fileName = path.mid(pos+1);
kdDebug() << "Found process " << oldPid << " running. It's: " << fileName << endl;
first_instance = fileName != "kmail" && fileName != "kontact";
@@ -199,17 +199,17 @@ void lockOrDie() {
"this machine. Running %2 more than once "
"can cause the loss of mail. You should not start %1 "
"unless you are sure that it is not already running.")
- .arg( programName, programName );
+ .tqarg( programName, programName );
// TQString::arg( st ) only replaces the first occurrence of %1
// with st while TQString::arg( s1, s2 ) replacess all occurrences
// of %1 with s1 and all occurrences of %2 with s2. So don't
// even think about changing the above to .arg( programName ).
else
msg = i18n("%1 seems to be running on another display on this "
"machine. Running %1 and %2 at the same "
"time can cause the loss of mail. You should not start %2 "
"unless you are sure that %1 is not running.")
- .arg( oldProgramName, programName );
+ .tqarg( oldProgramName, programName );
}
else {
if ( oldAppName == appName )
@@ -217,19 +217,19 @@ void lockOrDie() {
"than once can cause the loss of mail. You should not "
"start %1 on this computer unless you are sure that it is "
"not already running on %2.")
- .arg( programName, oldHostName );
+ .tqarg( programName, oldHostName );
else
msg = i18n("%1 seems to be running on %3. Running %1 and %2 at the "
"same time can cause the loss of mail. You should not "
"start %2 on this computer unless you are sure that %1 is "
"not running on %3.")
- .arg( oldProgramName, programName, oldHostName );
+ .tqarg( oldProgramName, programName, oldHostName );
}
KCursorSaver idle( KBusyPtr::idle() );
if ( KMessageBox::No ==
KMessageBox::warningYesNo( 0, msg, TQString(),
- i18n("Start %1").arg( programName ),
+ i18n("Start %1").tqarg( programName ),
i18n("Exit") ) ) {
exit(1);
}
@@ -199,17 +199,17 @@ void lockOrDie() {
// with st while TQString::arg( s1, s2 ) replacess all occurrences
// of %1 with s1 and all occurrences of %2 with s2. So don't
- // even think about changing the above to .arg( programName ).
+ // even think about changing the above to .tqarg( programName ).
else
msg = i18n("%1 seems to be running on another display on this "